@@ -8,14 +8,14 @@ class BaseSolver:
         self.query_type = query_type
 
     @abstractmethod
-    def get_operation(self, *args):
+    def get_operation(self, *args, **kwargs):
         raise NotImplementedError()
 
     @abstractmethod
-    def _get_operation(self, *args):
+    def _get_operation(self, *args, **kwargs):
         raise NotImplementedError()
 
     @abstractmethod
-    def run_query(self, graph_connector):
+    def run(self, graph_connector):
         raise NotImplementedError()
 
