@@ -15,7 +15,7 @@ class ApiServerTokenAuthFile(BaseK8Check):
         return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
-        if "command" in conf:
+        if conf.get("command") is not None:
             if "kube-apiserver" in conf["command"]:
                 if any(x.startswith('--token-auth-file') for x in conf["command"]):
                     return CheckResult.FAILED
